@@ -34,6 +34,18 @@ SMLM_REPRESENTATIONS = SearchWidget(
                         }
                     }
                     """
+)  #
+
+
+MULTISCALE_REPRESENTATIONS = SearchWidget(
+    query="""
+        query Search($search: String){
+            options: representations(name: $search, derivedTags: ["multiscale"]){
+                value: id
+                label: name
+            }
+        }
+        """
 )
 
 
@@ -68,12 +80,19 @@ class ArkitektWidget(QtWidgets.QWidget):
         self.agent.register_side(
             self.upload, widgets={"sample": MY_TOP_SAMPLES}, on_assign=self.upload
         )
+
         self.agent.register_side(
             self.open_locs,
             widgets={"rep": SMLM_REPRESENTATIONS},
             on_assign=self.open_locs,
         )
 
+        self.agent.register_side(
+            self.open_multiview,
+            widgets={"rep": MULTISCALE_REPRESENTATIONS},
+            on_assign=self.open_multiview,
+        )
+
         self.layout = QtWidgets.QVBoxLayout()
         self.layout.addWidget(self.magic_bar)
         self.setLayout(self.layout)
@@ -96,10 +115,19 @@ class ArkitektWidget(QtWidgets.QWidget):
 
         Args:
             rep (Representation): The image you want to display
-            stream (bool, optional): Do you want to stream the image or download it?
         """
         return self.helper.open_with_localizations(rep)
 
+    def open_multiview(self, rep: Representation):
+        """Open MultiView
+
+        Opens this Image with multiview
+
+        Args:
+            rep (Representation): The image you want to display
+        """
+        return self.helper.open_multiscale(rep)
+
     def upload(self, name: str = None, sample: Sample = None) -> Representation:
         """Upload an Active Image
 
@@ -112,8 +140,4 @@ class ArkitektWidget(QtWidgets.QWidget):
         Returns:
             Representation: The uploaded image from the app
         """
-        array = self.helper.get_active_layer_as_xarray()
-
-        return Representation.objects.from_xarray(
-            array, name=name, sample=sample, tags=[]
-        )
+        return self.helper.upload_everything(image_name=name, sample=sample)
